metadata(version="3.3.4")

require("re")

module("_markupbase.py")
